@@ -1,7 +1,7 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-our $VERSION = '5.2'; # VERSION
+our $VERSION = '5.3'; # VERSION
 
 use strict;
 use warnings;
@@ -35,6 +35,7 @@ use Sub::Exporter -setup => {
         es_basic_auth
         es_pattern
         es_connect
+        es_master
         es_request
         es_nodes
         es_indices
@@ -85,6 +86,7 @@ if( !defined $_OPTIONS_PARSED ) {
         'http-username:s',
         'http-password:s',
         'password-exec:s',
+        'master-only|M',
     );
     $_OPTIONS_PARSED = 1;
 }
@@ -119,6 +121,7 @@ my %DEF = (
                    exists $_GLOBALS{noop}         ? $_GLOBALS{noop} : undef,
     NOPROXY     => exists $opt{'keep-proxy'}      ? 0 :
                    exists $_GLOBALS{'keep-proxy'} ? $_GLOBALS{'keep-proxy'} : 1,
+    MASTERONLY  => exists $opt{'master-only'}     ? $opt{'master-only'} : 0,
     # HTTP Basic Authentication
     USERNAME    => exists $opt{'http-username'}       ? $opt{'http-username'} :
                    exists $_GLOBALS{'http-username'}  ? $_GLOBALS{'http-username'} : undef,
@@ -167,6 +170,7 @@ foreach my $literal ( @ORDERED ) {
 }
 
 our $CURRENT_VERSION;
+my  $CLUSTER_MASTER;
 
 
 sub es_globals {
@@ -308,6 +312,27 @@ sub es_connect {
 }
 
 
+sub es_master {
+    my ($instance) = @_;
+    if(!defined $instance && defined $CLUSTER_MASTER) {
+        return $CLUSTER_MASTER;
+    }
+    my $is_master = 0;
+    my @request = ('/_cluster/state/master_node');
+    unshift @request, $instance if defined $instance;
+
+    my $cluster = es_request(@request);
+    if( $cluster->{master_node} ) {
+        my $local = es_request('/_nodes/_local');
+        if ($local->{nodes} && $local->{nodes}{$cluster->{master_node}}) {
+            $is_master = 1;
+        }
+    }
+    $CLUSTER_MASTER = $is_master unless defined $instance;
+    return $is_master;
+}
+
+
 sub es_request {
     my $instance = ref $_[0] eq 'App::ElasticSearch::Utilities::Connection' ? shift @_ : es_connect();
 
@@ -340,14 +365,26 @@ sub es_request {
     $options->{index} = $index if defined $index;
     $index ||= '';
 
+
     # Figure out if we're modifying things
     my $modification = $url eq '_search' && $options->{method} eq 'POST' ? 0
                      : $options->{method} ne 'GET';
 
     my ($status,$res);
-    if( $DEF{NOOP} && $modification) {
-        output({color=>'cyan'}, "Called es_request($index/$options->{command}), but --noop and method is $options->{method}");
-        return;
+    if($modification) {
+        # Set NOOP if necessary
+        if(!$DEF{NOOP} && $DEF{MASTERONLY}) {
+            if( !es_master() ) {
+                $DEF{NOOP} = 1;
+            }
+        }
+
+        # Check for noop
+        if( $DEF{NOOP} ) {
+            my $flag = $DEF{MASTERONLY} && !es_master() ? '--master-only' : '--noop';
+            output({color=>'cyan'}, "Called es_request($index/$options->{command}), but $flag set and method is $options->{method}");
+            return;
+        }
     }
 
     # Make the request
@@ -566,10 +603,8 @@ sub es_index_shards {
     my %shards = map { $_ => 0 } qw(primaries replicas);
     my $result = es_request('_settings', {index=>$index});
     if( defined $result && is_hashref($result) )   {
-        $shards{primaries} = $CURRENT_VERSION < 1.0 ? $result->{$index}{settings}{'index.number_of_shards'}
-                                                    : $result->{$index}{settings}{index}{number_of_shards};
-        $shards{replicas}  = $CURRENT_VERSION < 1.0 ? $result->{$index}{settings}{'index.number_of_replicas'}
-                                                    : $result->{$index}{settings}{index}{number_of_replicas};
+        $shards{primaries} = $result->{$index}{settings}{index}{number_of_shards};
+        $shards{replicas}  = $result->{$index}{settings}{index}{number_of_replicas};
     }
 
     return wantarray ? %shards : \%shards;
@@ -602,19 +637,10 @@ sub es_index_fields {
 
     # Loop through the mappings, skipping _default_
     my @mappings = grep { $_ ne '_default_' } keys %{ $ref };
-    my %fieldcache;
+    my %fields;
     foreach my $mapping (@mappings) {
-        _find_fields(\%fieldcache,$ref->{$mapping});
+        _find_fields(\%fields,$ref->{$mapping});
     }
-
-    # Store full path
-    my %fields = %{ $fieldcache{full} };
-
-    # Now add unique aliases
-    my @uniqaliases = grep { not exists $fields{$_} }
-                      grep { $fieldcache{alias}->{$_} == 1 }
-                        keys %{ $fieldcache{alias} };
-    @fields{@uniqaliases} = ();
     # Return the results
     return wantarray ? sort keys %fields : [ sort keys %fields ];
 }
@@ -625,20 +651,9 @@ sub _add_fields {
 
     return unless @path;
 
-    # initialize the fields
-    $f->{full}  ||= {};
-    $f->{alias} ||= {};
-
     # Store the full path
     my $key = join('.', @path);
-    $f->{full}{$key} = 1;
-
-    # Aliases
-    my $alias = $key eq $path[-1] ? undef : $path[-1];
-    if( $alias ) {
-        $f->{alias}{$alias} ||= 0;
-        $f->{alias}{$alias}++;
-    }
+    $f->{$key} = 1;
 }
 
 sub _find_fields {
@@ -802,7 +817,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 5.2
+version 5.3
 
 =head1 SYNOPSIS
 
@@ -875,6 +890,10 @@ Returns a hashref of the pattern filter used to get the indexes
 Without options, this connects to the server defined in the args.  If passed
 an array ref, it will use that as the connection definition.
 
+=head2 es_request([$handle])
+
+Returns true (1) if the handle is to the the cluster master, or false (0) otherwise.
+
 =head2 es_request([$handle],$command,{ method => 'GET', uri_param => { a => 1 } }, {})
 
 Retrieve URL from ElasticSearch, returns a hash reference
