@@ -43,6 +43,7 @@ GetOptions(\%OPT, qw(
     tail
     timestamp:s
     top:s
+    interval:s
     with:s@
 ));
 
@@ -65,10 +66,10 @@ if( exists $OPT{prefix} ){
 
 #------------------------------------------------------------------------#
 # Documentation
-pod2usage(1) if $OPT{help};
+pod2usage({-sections => 'SYNOPSIS'}) if $OPT{help};
 pod2usage(-exitval => 0, -verbose => 2) if $OPT{manual};
 my $unknown_options = join ', ', grep /^--/, @ARGV;
-pod2usage({-exitval => 1, -msg =>"Unknown option(s): $unknown_options"}) if $unknown_options;
+pod2usage({-exitval => 1, -sections => 'SYNOPSIS', -msg =>"Unknown option(s): $unknown_options"}) if $unknown_options;
 
 #--------------------------------------------------------------------------#
 # App Config
@@ -77,8 +78,8 @@ my %CONFIG = (
     format    => (exists $OPT{format} && length $OPT{format})       ? lc $OPT{format}         : 'yaml',
     timestamp => (exists $OPT{timestamp} && length $OPT{timestamp}) ? $OPT{timestamp}         :
                  defined es_globals('timestamp')                    ? es_globals('timestamp') : '@timestamp',
+    summary   => $OPT{top} && ( !$OPT{by} && !$OPT{with} && !$OPT{interval} ),
 );
-
 #------------------------------------------------------------------------#
 # Handle Indices
 my $ORDER = exists $OPT{asc} && $OPT{asc} ? 'asc' : 'desc';
@@ -110,7 +111,7 @@ if( exists $OPT{sort} && length $OPT{sort} ) {
         map { /:/ ? +{ split /:/ } : $_ }
         split /,/,
         $OPT{sort}
-    ];
+    ]
 }
 $q->set_sort($SORT);
 
@@ -122,12 +123,17 @@ if( $OPT{fields} ) {
     show_fields();
     exit 0;
 }
-pod2usage({-exitval => 1, -msg => 'No search string specified'}) unless keys %{ $q->query->{bool} };
-pod2usage({-exitval => 1, -msg => 'Cannot use --tail and --top together'}) if exists $OPT{tail} && $OPT{top};
-pod2usage({-exitval => 1, -msg => 'Cannot use --tail and --sort together'}) if exists $OPT{tail} && $OPT{sort};
-pod2usage({-exitval => 1, -msg => 'Cannot use --sort along with --asc or --desc'})
+# Improper Usage
+pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'No search string specified'})
+    unless keys %{ $q->query->{bool} };
+pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Cannot use --tail and --top together'})
+    if exists $OPT{tail} && $OPT{top};
+pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Cannot use --tail and --sort together'})
+    if exists $OPT{tail} && $OPT{sort};
+pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Cannot use --sort along with --asc or --desc'})
     if $OPT{sort} && ($OPT{asc} || $OPT{desc});
-pod2usage({-exitval => 1, -msg => 'Please specify --show with --tail'}) if exists $OPT{tail} && !@SHOW;
+pod2usage({-exitval=>1, -verbose=>0, -sections=>'SYNOPSIS', -msg=>'Please specify --show with --tail'})
+    if exists $OPT{tail} && !@SHOW;
 
 # Process extra parameters
 if( exists $OPT{exists} ) {
@@ -207,6 +213,15 @@ if( exists $OPT{top} ) {
         $agg{$top_agg}->{size} = $CONFIG{size};
     }
     $q->add_aggregations( top => \%agg );
+
+    if( $OPT{interval} ) {
+        $q->wrap_aggregations( step => {
+            date_histogram => {
+                field    => $CONFIG{timestamp},
+                interval => $OPT{interval},
+            }
+        });
+    }
 }
 elsif(exists $OPT{tail}) {
     $q->set_size(20);
@@ -295,69 +310,76 @@ AGES: while( !$DONE && @AGES ) {
         my $hits = is_arrayref($result->{hits}{hits}) ? $result->{hits}{hits} : [];
 
         # Handle Aggregations
-        my $aggs = exists $result->{aggregations} ? $result->{aggregations}{top}{buckets} : [];
-        if( @$aggs ) {
-            output({color=>'cyan'},$agg_header) unless $OPT{'no-header'};
-            foreach my $agg ( @$aggs ) {
-                $AGGS_TOTALS{$agg->{key}} ||= 0;
-                $AGGS_TOTALS{$agg->{key}} += $agg->{doc_count};
-                my @out = ();
+        if( exists $result->{aggregations} ) {
+            my $steps = exists $result->{aggregations}{step} ? $result->{aggregations}{step}{buckets}
+                      : [ $result->{aggregations} ];
+            my $indent = exists $result->{aggregations}{step} ? 1 : 0;
+            foreach my $step ( @$steps ) {
+                my $aggs = exists $step->{top} ? $step->{top}{buckets} : [];
+                if( exists $step->{key_as_string} ) {
+                    output({color=>'cyan',clear=>1}, sprintf "%d\t%s", @{$step}{qw(doc_count key_as_string)});
+                }
+                if( @$aggs ) {
+                    output({color=>'cyan',indent=>$indent},$agg_header) unless $OPT{'no-header'};
+                    foreach my $agg ( @$aggs ) {
+                        $AGGS_TOTALS{$agg->{key}} ||= 0;
+                        $AGGS_TOTALS{$agg->{key}} += $agg->{doc_count};
+                        my @out = ();
 
-                foreach my $k (qw(score doc_count bg_count key)) {
-                    next unless exists $agg->{$k};
-                    my $value = delete $agg->{$k};
-                    push @out, defined $value ? ($k eq 'score' ? sprintf "%0.3f", $value : $value ) : '-';
-                }
-                if(exists $agg->{by} ) {
-                    my $by = delete $agg->{by};
-                    if( exists $by->{value} ) {
-                        unshift @out, $by->{value};
-                    }
-                }
-                # Handle the --with elements
-                my %subaggs = ();
-                if( keys %{ $agg } ) {
-                    foreach my $k (sort keys %{ $agg }) {
-                        next unless is_hashref($agg->{$k});
-                        if( exists $agg->{$k}{buckets} ) {
-                            my @sub;
-                            foreach my $subagg (@{ $agg->{$k}{buckets} }) {
-                                my @elms = ();
-                                next unless exists $subagg->{key};
-                                push @elms, $subagg->{key};
-                                foreach my $dk (qw(doc_count score bg_count)) {
-                                    next unless exists $subagg->{$dk};
-                                    my $v = delete $subagg->{$dk};
-                                    push @elms, defined $v ? ($dk eq 'score' ? sprintf "%0.3f", $v : $v ) : '-';
-                                }
-                                push @sub, \@elms;
+                        foreach my $k (qw(score doc_count bg_count key)) {
+                            next unless exists $agg->{$k};
+                            my $value = delete $agg->{$k};
+                            push @out, defined $value ? ($k eq 'score' ? sprintf "%0.3f", $value : $value ) : '-';
+                        }
+                        if(exists $agg->{by} ) {
+                            my $by = delete $agg->{by};
+                            if( exists $by->{value} ) {
+                                unshift @out, $by->{value};
                             }
-                            $subaggs{$k} = \@sub if @sub;
                         }
-                    }
-                }
-                if( keys %subaggs ) {
-                    foreach my $subagg (sort keys %subaggs) {
-                        foreach my $extra ( @{ $subaggs{$subagg} } ) {
-                            my @copy = @out;
-                            splice @copy, exists $OPT{by} ? 2 : 1, 0, $subagg, @{ $extra };
-                            output({data=>1},
-                                join "\t", @copy
-                            );
+                        # Handle the --with elements
+                        my %subaggs = ();
+                        if( keys %{ $agg } ) {
+                            foreach my $k (sort keys %{ $agg }) {
+                                next unless is_hashref($agg->{$k});
+                                if( exists $agg->{$k}{buckets} ) {
+                                    my @sub;
+                                    foreach my $subagg (@{ $agg->{$k}{buckets} }) {
+                                        my @elms = ();
+                                        next unless exists $subagg->{key};
+                                        push @elms, $subagg->{key};
+                                        foreach my $dk (qw(doc_count score bg_count)) {
+                                            next unless exists $subagg->{$dk};
+                                            my $v = delete $subagg->{$dk};
+                                            push @elms, defined $v ? ($dk eq 'score' ? sprintf "%0.3f", $v : $v ) : '-';
+                                        }
+                                        push @sub, \@elms;
+                                    }
+                                    $subaggs{$k} = \@sub if @sub;
+                                }
+                            }
                         }
+                        if( keys %subaggs ) {
+                            foreach my $subagg (sort keys %subaggs) {
+                                foreach my $extra ( @{ $subaggs{$subagg} } ) {
+                                    output({indent=>$indent,data=>1},
+                                        join "\t", @out, $subagg, @{ $extra }
+                                    );
+                                }
+                            }
+                        }
+                        else {
+                            # Simple output
+                            output({indent=>$indent,data=>!$CONFIG{summary}}, join("\t",@out));
+                        }
+                        $displayed++;
                     }
+                    $TOTAL_HITS = exists $result->{aggegrations}{top}{other} ? $result->{aggregations}{top}{other} + $displayed : $TOTAL_HITS;
                 }
-                else {
-                    # Simple output
-                    output(exists $OPT{by} ? {data=>1} : {}, join("\t",@out));
+                elsif(exists $result->{aggregations}{top}) {
+                    output({indent=>1,color=>'red'}, "= No results.");
                 }
-                $displayed++;
             }
-            $TOTAL_HITS = exists $result->{aggegrations}{top}{other} ? $result->{aggregations}{top}{other} + $displayed : $TOTAL_HITS;
-            next AGES;
-        }
-        elsif(exists $result->{aggregations}{top}) {
-            output({indent=>1,color=>'red'}, "= No results.");
             next AGES;
         }
 
@@ -457,7 +479,7 @@ output({stderr=>1,color=>'yellow'},
     ),
 );
 
-if(!exists $OPT{by} && !exists $OPT{with} && keys %AGGS_TOTALS) {
+if($CONFIG{summary} && keys %AGGS_TOTALS) {
     output({color=>'yellow'}, '#', '# Totals across batch', '#');
     output({color=>'cyan'},$agg_header);
     foreach my $k (sort { $AGGS_TOTALS{$b} <=> $AGGS_TOTALS{$a} } keys %AGGS_TOTALS) {
@@ -555,7 +577,7 @@ es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily
 
 =head1 VERSION
 
-version 5.2
+version 5.3
 
 =head1 SYNOPSIS
 
@@ -571,6 +593,7 @@ Options:
     --by                Perform an aggregation using the result of this, example: --by cardinality:@fields.src_ip
     --with              Perform a sub aggregation on the query
     --match-all         Enables the ElasticSearch match_all operator
+    --interval          When running aggregations, wrap the aggreation in a date_histogram with this interval
     --prefix            Takes "field:string" and enables the Lucene prefix query for that field
     --exists            Field which must be present in the document
     --missing           Field which must not be present in the document
@@ -774,6 +797,11 @@ Produces:
 You may sub aggregate using any L<bucket agggregation|https://www.elastic.co/guide/en/elasticsearch/reference/master/search-aggregations-bucket.html>
 as long as the aggregation provides a B<key> element.  Additionally, doc_count, score, and bg_count will be reported in the output.
 
+=item B<interval>
+
+When performing aggregations, wrap those aggregations in a date_histogram of this interval.  This
+helps flush out "what changed in the last hour."
+
 =item B<match-all>
 
 Apply the ElasticSearch "match_all" search operator to query on all documents in the index.
